
rattail-dash
============

This package contains some helper logic, as well as a sample app, to
show how a `Dash`_ app can display Rattail (and specifically
Trainwreck) data.

.. _Dash: https://dash.plot.ly/

Rattail is a retail software framework, released under the GNU General
Public License.

Please see Rattail's `home page`_ for more information.

.. _`home page`: https://rattailproject.org/
